This section presents a list of learning resources to help understanding the foundations of deep learning with audio.

## Signal Processing Basics

- [Compact primer on digital signal processing](https://jackschaedler.github.io/circles-sines-signals/index.html)
- [What is a fourier transform? by 3Blue1Brown](https://youtu.be/spUNpyF58BY)
- [How to normalize spectrograms](https://enzokro.dev/spectrogram_normalizations/2020/09/10/Normalizing-spectrograms-for-deep-learning.html)
- [What is a Spectrogram](https://www.youtube.com/watch?v=_FatxGN3vAM)
- [Audio Signal Processing for Machine Learning](https://www.youtube.com/playlist?list=PL-wATfeyAMNqIee7cH3q1bh4QJFAaeNv0)

## Audio generation

- [Generating music in the waveform domain](https://benanne.github.io/2020/03/24/audio-generation.html)
